@@ -18,10 +18,24 @@ import minio
 import redis
 import uuid
 import requests
+import hashlib
 
 
 class UniUtil:
     """统一处理工具类"""
+    
+    @staticmethod
+    def get_file_md5(filepath: str):
+        """获取文件的哈希值MD5"""
+        m = hashlib.md5()
+        with open(filepath, "rb") as fr:
+            while True:
+                # 将文件分块读取
+                data = fr.read(1024)
+                if not data:
+                    break
+                m.update(data)
+        return m.hexdigest()
 
     @staticmethod
     def verify_url(url: str):
@@ -886,14 +900,14 @@ class RedisUtil:
         """字符串设置值
         """
         key = f'{cls.PREFIX}:{key}' if cls.PREFIX else key
-        cls.CONN.set(key, val)
+        return cls.CONN.set(key, val)
 
     @classmethod
     def lgetall(cls, key: str):
         """列表获取值
         """
         key = f'{cls.PREFIX}:{key}' if cls.PREFIX else key
-        cls.CONN.lrange(key, 0, -1)
+        return cls.CONN.lrange(key, 0, -1)
 
     @classmethod
     def lsetall(cls, key: dict, vals: list):
